@@ -27,4 +27,6 @@ class CodeSplitter:
             moved_blocks=moved_blocks, non_moved_blocks=non_moved_blocks, new_dir_path=init_file_path.parent
         ).execute()
         # 5. Add import statements to the __init__.py file
-        GenerateInitFileService(init_file_path=init_file_path, moved_blocks=moved_blocks).execute()
+        GenerateInitFileService(
+            init_file_path=init_file_path, moved_blocks=moved_blocks, non_moved_blocks=non_moved_blocks
+        ).execute()
